@@ -32,27 +32,15 @@ from botocore.exceptions import UnknownSignatureVersionError
 from botocore.exceptions import NoCredentialsError
 from botocore.utils import normalize_url_path
 from botocore.compat import HTTPHeaders
+from botocore.compat import quote, unquote, urlsplit, parse_qsl
 from six.moves import http_client
 
 logger = logging.getLogger(__name__)
 
-try:
-    from urllib.parse import quote
-    from urllib.parse import unquote
-    from urllib.parse import urlsplit
-    from urllib.parse import parse_qsl
-except ImportError:
-    from urllib import quote
-    from urllib import unquote
-    from urlparse import urlsplit
-    from urlparse import parse_qsl
 
-
-PostContentType = 'application/x-www-form-urlencoded; charset=UTF-8'
 EMPTY_SHA256_HASH = (
     'e3b0c44298fc1c149afbf4c8996fb92427ae41e4649b934ca495991b7852b855')
 
-
 class SigV2Auth(object):
     """
     Sign a request with Signature V2.
@@ -387,13 +375,11 @@ class HmacV1Auth(object):
                                                            signature))
 
 
-def get_auth(signature_version, *args, **kw):
-    if signature_version == 'v2':
-        return SigV2Auth(*args, **kw)
-    elif signature_version == 'v4':
-        return SigV4Auth(*args, **kw)
-    elif signature_version == 's3':
-        return HmacV1Auth(*args, **kw)
-    elif signature_version == 'v3':
-        return SigV3Auth(*args, **kw)
-    raise UnknownSignatureVersionError(signature_version=signature_version)
+# Defined at the bottom instead of the top of the module because the Auth
+# classes weren't defined yet.
+AUTH_TYPE_MAPS = {
+    'v2': SigV2Auth,
+    'v4': SigV4Auth,
+    'v3': SigV3Auth,
+    's3': HmacV1Auth,
+}
