@@ -20,11 +20,16 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 # IN THE SOFTWARE.
 #
+import logging
+
 from .endpoint import get_endpoint
 from .operation import Operation
 from .exceptions import ServiceNotInRegionError, NoRegionError
 
 
+logger = logging.getLogger(__name__)
+
+
 class Service(object):
     """
     A service, such as Elastic Compute Cloud (EC2).
@@ -44,23 +49,33 @@ class Service(object):
         self.timestamp_format = 'iso8601'
         sdata = session.get_service_data(service_name, provider_name)
         self.__dict__.update(sdata)
+        self._operations_data = self.__dict__.pop('operations')
+        self._operations = None
         self.session = session
         self.provider_name = provider_name
         self.path = path
         self.port = port
         self.cli_name = service_name
-        self._operations_data = self.operations
-        self.operations = []
+
+    def _create_operation_objects(self):
+        logger.debug("Creating operation objects for: %s", self)
+        operations = []
         for operation_name in self._operations_data:
             data = self._operations_data[operation_name]
             data['name'] = operation_name
             op = Operation(self, data)
-            self.operations.append(op)
-            setattr(self, op.py_name, op)
+            operations.append(op)
+        return operations
 
     def __repr__(self):
         return 'Service(%s)' % self.endpoint_prefix
 
+    @property
+    def operations(self):
+        if self._operations is None:
+            self._operations = self._create_operation_objects()
+        return self._operations
+
     @property
     def region_names(self):
         return self.metadata['regions'].keys()
@@ -138,4 +153,5 @@ def get_service(session, service_name, provider_name='aws'):
     :type provider_name: str
     :param provider_name: The name of the provider.
     """
+    logger.debug("Creating service object for: %s", service_name)
     return Service(session, provider_name, service_name)
